==> haskell-vault-0.3.1.5-182-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-JqfiBpBvd5f8D8LafNRZDu
key:                  vault-0.3.1.5-JqfiBpBvd5f8D8LafNRZDu
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  ee5d9a9b6fbf9531b71ce645c27f8370
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-JqfiBpBvd5f8D8LafNRZDu
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.5-187-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ
key:                  vault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  711154c288e2ba479ca537dd70fec0e8
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
